[igt-dev] [PATCH] i915/gem_eio: Removed early timeout check for forced reset completion

krishnaiah.bommu at intel.com krishnaiah.bommu at intel.com
Tue Apr 26 11:31:06 UTC 2022


From: Bommu Krishnaiah <krishnaiah.bommu at intel.com>

GUC log capture is taking more time on few platforms, so removing
early timeout check for forced reset completion.
Test is having same check in later.

Signed-off-by: Krishnaiah Bommu <krishnaiah.bommu at intel.com>
Cc: Kamil Konieczny <kamil.konieczny at linux.intel.com>
Cc: John Harrison <john.c.harrison at intel.com>
Cc: Andi Shyti <andi.shyti at intel.com>
---
 tests/i915/gem_eio.c | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/tests/i915/gem_eio.c b/tests/i915/gem_eio.c
index d9689534d5a..30eaceb1b3d 100644
--- a/tests/i915/gem_eio.c
+++ b/tests/i915/gem_eio.c
@@ -72,8 +72,9 @@ static void trigger_reset(int fd)
 	igt_kmsg(KMSG_DEBUG "Forcing GPU reset\n");
 	igt_force_gpu_reset(fd);
 
-	/* The forced reset should be immediate */
-	igt_assert_lte(igt_seconds_elapsed(&ts), 2);
+	/* The forced reset should be immediate non GUC platforms */
+	if (!gem_using_guc_submission(fd))
+		igt_assert_lte(igt_seconds_elapsed(&ts), 2);
 
 	/* And just check the gpu is indeed running again */
 	igt_kmsg(KMSG_DEBUG "Checking that the GPU recovered\n");
-- 
2.25.1



More information about the igt-dev mailing list